==> quanyi-center-api-0.0.48-20231219.024740-5-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/partner/RemotePartnerService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.partner;


import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.partner.PartnerDto;
import cn.com.duiba.quanyi.center.api.param.PartnerPageQueryParam;

import java.util.List;
import java.util.Set;

/**
 * 客户管理
 *
 * @author kjj mybatis generator
 * @date 2023-08-07
 */
@AdvancedFeignClient
public interface RemotePartnerService {

    /**
     * 根据主键查询
     *
     * @param id 主键
     * @return 合作客户
     */
    PartnerDto selectById(Long id);

    /**
     * 根据名称查询
     *
     * @param partnerName 名称
     * @return
     */
    PartnerDto findByName(String partnerName);

    /**
     * 根据主键查询
     *
     * @param ids 主键
     * @return 合作客户
     */
    List<PartnerDto> selectByIdList(Set<Long> ids);


    /**
     * 新增
     *
     * @param entity 合作客户
     * @return 执行结果
     */
    Long insert(PartnerDto entity);

    /**
     * 更新
     *
     * @param entity 合作客户
     * @return 执行结果
     */
    int update(PartnerDto entity);

    /**
     * 物理删除
     *
     * @param id 主键
     * @return 执行结果
     */
    int delete(Long id);

    /**
     * 分页查询
     *
     * @return 活动
     */
    List<PartnerDto> selectPage(PartnerPageQueryParam param);

    /**
     * count
     *
     * @param partnerName 客户名称
     * @param createPersonId 创建人id
     * @return 匹配结果的行数
     */
    Integer count(String partnerName, Long createPersonId);

    /**
     * 查询所有客户
     *
     * @return 活动
     */
    List<PartnerDto> findAll();

    /**
     * 根据客户名称模糊查询对应的客户信息
     * @param customName 客户名称
     * @return 对应的集合信息
     */
    List<PartnerDto> findByNameLike(String customName);
}

==> quanyi-center-api-0.0.49-20231220.053610-12-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/partner/RemotePartnerService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.partner;


import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.partner.PartnerDto;
import cn.com.duiba.quanyi.center.api.param.PartnerPageQueryParam;

import java.util.List;
import java.util.Set;

/**
 * 客户管理
 *
 * @author kjj mybatis generator
 * @date 2023-08-07
 */
@AdvancedFeignClient
public interface RemotePartnerService {

    /**
     * 根据主键查询
     *
     * @param id 主键
     * @return 合作客户
     */
    PartnerDto selectById(Long id);

    /**
     * 根据名称查询
     *
     * @param partnerName 名称
     * @return
     */
    PartnerDto findByName(String partnerName);

    /**
     * 根据主键查询
     *
     * @param ids 主键
     * @return 合作客户
     */
    List<PartnerDto> selectByIdList(Set<Long> ids);


    /**
     * 新增
     *
     * @param entity 合作客户
     * @return 执行结果
     */
    Long insert(PartnerDto entity);

    /**
     * 更新
     *
     * @param entity 合作客户
     * @return 执行结果
     */
    int update(PartnerDto entity);

    /**
     * 物理删除
     *
     * @param id 主键
     * @return 执行结果
     */
    int delete(Long id);

    /**
     * 分页查询
     *
     * @return 活动
     */
    List<PartnerDto> selectPage(PartnerPageQueryParam param);

    /**
     * count
     *
     * @param partnerPageQueryParam 查询参数
     * @return 匹配结果的行数
     */
    Integer count(PartnerPageQueryParam partnerPageQueryParam);

    /**
     * 查询所有客户
     *
     * @return 活动
     */
    List<PartnerDto> findAll();
}
